@@ -347,7 +347,7 @@ PLAN_TASK_SCHEMA = '''{
                                         ],
                                         "type": "object"
                                     },
-                                    "maxItems": 10,
+                                    "maxItems": 50,
                                     "minItems": 1,
                                     "type": "array"
                                 },
@@ -727,6 +727,11 @@ PLAN_TASK_SCHEMA = '''{
                                                     "maximum": 180,
                                                     "minimum": -180,
                                                     "type": "number"
+                                                },
+                                                "name": {
+                                                    "maxLength": 1024,
+                                                    "minLength": 0,
+                                                    "type": "string"
                                                 }
                                             },
                                             "required": [
@@ -933,7 +938,7 @@ PLAN_TASK_SCHEMA = '''{
                                     "nullable": false,
                                     "properties": {
                                         "cost_per_unit": {
-                                            "default": 0,
+                                            "default": 0.001,
                                             "format": "double",
                                             "maximum": 10000,
                                             "minimum": 0,
@@ -958,7 +963,7 @@ PLAN_TASK_SCHEMA = '''{
                                 "type": "array"
                             },
                             "cost_per_shift": {
-                                "default": 0,
+                                "default": 0.001,
                                 "format": "double",
                                 "maximum": 100000,
                                 "minimum": 0,
